const path = require("path");

module.exports = grunt => {
    grunt.initConfig({
        pkg: grunt.file.readJSON("package.json"),
        clean: {
            default: ["dist/"],
        },
        cssmin: {
            target: {
                files: {
                    "dist/template.css": "src/main/css/main.css",
                },
            },
        },
        focus: {
            dev: {
                include: ["css", "ts"],
            },
        },
        watch: {
            css: {
                files: ["src/main/**/*.css"],
                tasks: ["cssmin"],
            },
            ts: {
                files: ["src/main/**/*.ts"],
                tasks: ["webpack:dev"],
            },
        },
        webpack: {
            options: {
                entry: "./src/main/js/Main.ts",
                module: {
                    rules: [
                        {
                            test: /\.ts$/,
                            use: "ts-loader",
                            exclude: /node_modules/,
                        },
                    ],
                },
                resolve: {
                    extensions: [".ts"],
                },
                output: {
                    filename: "template.js",
                    path: path.resolve(__dirname, "dist/"),
                },
            },
            dev: {
                mode: "development",
                devtool: "inline-source-map",
            },
            deploy: {
                mode: "production",
            },
        },
    });

    grunt.loadNpmTasks("grunt-contrib-clean");
    grunt.loadNpmTasks("grunt-contrib-cssmin");
    grunt.loadNpmTasks("grunt-contrib-watch");
    grunt.loadNpmTasks("grunt-focus");
    grunt.loadNpmTasks("grunt-webpack");

    grunt.registerTask("dev", ["clean", "webpack:dev", "cssmin"]);
    grunt.registerTask("dev:server", ["dev", "focus:dev"]);
    grunt.registerTask("deploy", ["clean", "webpack:deploy", "cssmin"]);

    grunt.registerTask("default", ["dev"]);
};
